#!/usr/bin/ruby
# frozen_string_literal: true

require_relative 'user'
require_relative 'message'

##
# +Monday+, +August+ +24+ +2020+
# ===This object represents an incoming callback query from a callback button in an inline keyboard.
# If the button that originated the query was
# attached to a message sent by the bot, the field message will be present.
# If the button was attached to a message sent via the bot (in inline mode),
# the field inline_message_id will be present. Exactly one of the fields data
# or game_short_name will be present.
class CallbackQuery
  def initialize(query) # :nodoc:
    @query = query
  end

  # Unique identifier for this query.
  def id
    @query.id
  end

  # Sender. Returns User object
  def from
    User.new(@query.from)
  end

  # +Optional+. Message with the callback button that originated the query.
  # Note that message content and message date will not be available if
  # the message is too old.
  def message
    data = @query.message
    return Message.new(data) if data

    false
  end

  # +Optional.+ Identifier of the message sent via the bot in inline mode,
  # that originated the query.
  def inline_message_id
    @query.inline_message_id
  end

  # Global identifier, uniquely corresponding to the chat to which the
  # message with the callback button was sent. Useful for high scores
  # in games.
  def chat_instance
    @query.chat_instance
  end

  # +Optional.+ Data associated with the callback button. Be aware that
  # a bad client can send arbitrary data in this field.
  def data
    @query.data
  end

  # +Optional.+ Short name of a Game to be returned, serves as the unique
  # identifier for the game
  def game_short_name
    @query.game_short_name
  end
end
